==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/callgraph/CallGraphTagger.h <==
// public class soot.jimple.toolkits.annotation.callgraph.CallGraphTagger

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class d69823f0bb29f9ef soot_jimple_toolkits_annotation_callgraph_CallGraphTagger

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger_H_
#define _JC_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_refs	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$refs	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$nonrefs	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vmethods	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtable	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object *_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$method$v$23317532ec57f2d5(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vmethods	soot_jimple_toolkits_annotation_callgraph_CallGraphTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object	*methodToContexts;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$refs {
    _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_refs	soot_jimple_toolkits_annotation_callgraph_CallGraphTagger;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_nonrefs	soot_jimple_toolkits_annotation_callgraph_CallGraphTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object {
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_callgraph_CallGraphTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/callgraph/CallGraphTagger.h <==
// public class soot.jimple.toolkits.annotation.callgraph.CallGraphTagger

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class d69823f0bb29f9ef soot_jimple_toolkits_annotation_callgraph_CallGraphTagger

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger_H_
#define _JC_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_refs	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$refs	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$nonrefs	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vmethods	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtable	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object *_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$method$v$23317532ec57f2d5(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vmethods	soot_jimple_toolkits_annotation_callgraph_CallGraphTagger;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_MethodToContexts$object	*methodToContexts;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$refs {
    _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_refs	soot_jimple_toolkits_annotation_callgraph_CallGraphTagger;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$sub_nonrefs	soot_jimple_toolkits_annotation_callgraph_CallGraphTagger;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$object {
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$vtype _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_callgraph_CallGraphTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_callgraph_CallGraphTagger_H_ */
